package com.sun.xml.internal.ws.message;

import java.util.Iterator;
import com.sun.istack.internal.Nullable;
import java.io.IOException;
import javax.xml.ws.WebServiceException;
import com.sun.xml.internal.ws.resources.EncodingMessages;
import java.util.HashMap;
import com.sun.xml.internal.ws.api.message.Attachment;
import java.util.Map;
import com.sun.xml.internal.ws.encoding.MimeMultipartParser;
import com.sun.xml.internal.ws.api.message.AttachmentSet;

public final class MimeAttachmentSet implements AttachmentSet
{
    private final MimeMultipartParser mpp;
    private Map<String, Attachment> atts;
    
    public MimeAttachmentSet(MimeMultipartParser mpp) {
        this.atts = new HashMap();
        this.mpp = mpp;
    }
    
    @Nullable
    public Attachment get(String contentId) {
        Attachment att = (Attachment)this.atts.get(contentId);
        if (att != null) {
            return att;
        }
        try {
            att = this.mpp.getAttachmentPart(contentId);
            if (att != null) {
                this.atts.put(contentId, att);
            }
        }
        catch (IOException e) {
            throw new WebServiceException(EncodingMessages.NO_SUCH_CONTENT_ID(contentId), e);
        }
        return att;
    }
    
    public boolean isEmpty() {
        return this.atts.size() <= 0 && this.mpp.getAttachmentParts().isEmpty();
    }
    
    public void add(Attachment att) {
        this.atts.put(att.getContentId(), att);
    }
    
    public Iterator<Attachment> iterator() {
        Map<String, Attachment> attachments = this.mpp.getAttachmentParts();
        for (Map.Entry<String, Attachment> att : attachments.entrySet()) {
            if (this.atts.get(att.getKey()) == null) {
                this.atts.put(att.getKey(), att.getValue());
            }
            else {
                continue;
            }
        }
        return this.atts.values().iterator();
    }
}
